# winreg-helpers #

Helper functions for reading/writing to the Windows Registry.

-------------------------------------------------------------------------------

Install
-------

The latest [`winreg-helpers` release][1] is available as a
[Conda][2] package from the [`sci-bots`][3] channel.

To install `winreg-helpers` in an **activated Conda environment**, run:

    conda install -c sci-bots winreg-helpers

-------------------------------------------------------------------------------

License
-------

This project is licensed under the terms of the [BSD license](/LICENSE.md)

-------------------------------------------------------------------------------

Contributors
------------

 - Christian Fobel ([@sci-bots](https://github.com/sci-bots))


[1]: https://github.com/sci-bots/winreg-helpers
[2]: https://conda.io/docs/
[3]: https://anaconda.org/sci-bots
